==> epstool-3.0.zip: epstool-3.0/src/ceps.h <==
/* Copyright (C) 1993-2002 Ghostgum Software Pty Ltd.  All rights reserved.

  This software is provided AS-IS with no warranty, either express or
  implied.

  This software is distributed under licence and may not be copied,
  modified or distributed except as expressly authorised under the terms
  of the licence contained in the file LICENCE in this distribution.

  For more information about licensing, please refer to
  http://www.ghostgum.com.au/ or contact Ghostsgum Software Pty Ltd, 
  218 Gallaghers Rd, Glen Waverley VIC 3150, AUSTRALIA, 
  Fax +61 3 9886 6616.
*/

/* $Id: ceps.h,v 1.4 2002/08/24 05:33:31 ghostgum Exp $ */

/* EPS preview manipulation */

int write_tiff(FILE *f, IMAGE *img, CDSCBBOX devbbox, float xdpi, float ydpi, 
    BOOL tiff4, BOOL use_packbits);

int extract_doseps(Doc *doc, LPCTSTR outname, BOOL preview);
int make_eps_tiff(Doc *doc, IMAGE *img, CDSCBBOX devbbox, 
    CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    float xdpi, float ydpi, BOOL tiff4, BOOL use_packbits, LPCTSTR epsname);
int make_eps_user(Doc *doc, LPCTSTR preview_name, LPCTSTR epsname);
int make_eps_interchange(Doc *doc, IMAGE *img, CDSCBBOX devbbox, 
    CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    LPCTSTR epsname);
int make_eps_metafile(Doc *doc, IMAGE *img, CDSCBBOX devbbox, 
    CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    float xdpi, float ydpi, LPCTSTR epsname);
int copy_page_temp(Doc *doc, FILE *f, int page);
int copy_eps(Doc *doc, LPCTSTR epsname, CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    int offset, BOOL dcs2_multi);
int copy_dcs2(Doc *doc, FILE *docfile, FILE *epsfile, LPCTSTR epsname,
    int offset, BOOL dcs2_multi, BOOL write_all, BOOL missing_separations,
    unsigned long *complen, FILE *composite);

==> epstool-3.02.zip: epstool-3.02/src/ceps.h <==
/* Copyright (C) 1993-2003 Ghostgum Software Pty Ltd.  All rights reserved.

  This software is provided AS-IS with no warranty, either express or
  implied.

  This software is distributed under licence and may not be copied,
  modified or distributed except as expressly authorised under the terms
  of the licence contained in the file LICENCE in this distribution.

  For more information about licensing, please refer to
  http://www.ghostgum.com.au/ or contact Ghostsgum Software Pty Ltd, 
  218 Gallaghers Rd, Glen Waverley VIC 3150, AUSTRALIA, 
  Fax +61 3 9886 6616.
*/

/* $Id: ceps.h,v 1.7 2003/02/28 09:31:05 ghostgum Exp $ */

/* EPS preview manipulation */

int write_tiff(GFile *f, IMAGE *img, CDSCBBOX devbbox, float xdpi, float ydpi, 
    BOOL tiff4, BOOL use_packbits);

int extract_doseps(Doc *doc, LPCTSTR outname, BOOL preview);
int make_eps_tiff(Doc *doc, IMAGE *img, CDSCBBOX devbbox, 
    CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    float xdpi, float ydpi, BOOL tiff4, BOOL use_packbits, BOOL reverse,
    LPCTSTR epsname);
int make_eps_user(Doc *doc, LPCTSTR preview_name, BOOL reverse, 
    LPCTSTR epsname);
int make_eps_interchange(Doc *doc, IMAGE *img, CDSCBBOX devbbox, 
    CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    LPCTSTR epsname);
int make_eps_metafile(Doc *doc, IMAGE *img, CDSCBBOX devbbox, 
    CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    float xdpi, float ydpi, BOOL reverse, LPCTSTR epsname);
int copy_page_temp(Doc *doc, GFile *f, int page);
int copy_eps(Doc *doc, LPCTSTR epsname, CDSCBBOX *bbox, CDSCFBBOX *hires_bbox,
    int offset, BOOL dcs2_multi);

typedef struct RENAME_SEPARATION_s RENAME_SEPARATION;
struct RENAME_SEPARATION_s {
    char *oldname;
    char *newname;
    RENAME_SEPARATION *next;
};
int copy_dcs2(Doc *doc, GFile *docfile, GFile *epsfile, LPCTSTR epsname,
    int offset, BOOL dcs2_multi, BOOL write_all, BOOL missing_separations,
    FILE_POS *complen, GFile *composite, RENAME_SEPARATION *rs);
